@@ -68,6 +68,7 @@ class TeleBot:
         self.message_handlers = []
         self.inline_handlers = []
         self.chosen_inline_handlers = []
+        self.callback_query_handlers = []
 
         self.threaded = threaded
         if self.threaded:
@@ -124,6 +125,7 @@ class TeleBot:
         new_messages = []
         new_inline_querys = []
         new_chosen_inline_results = []
+        new_callback_querys = []
         for update in updates:
             if update.update_id > self.last_update_id:
                 self.last_update_id = update.update_id
@@ -133,6 +135,8 @@ class TeleBot:
                 new_inline_querys.append(update.inline_query)
             if update.chosen_inline_result:
                 new_chosen_inline_results.append(update.chosen_inline_result)
+            if update.callback_query:
+                new_callback_querys.append(update.callback_query)
         logger.debug('Received {0} new updates'.format(len(updates)))
         if len(new_messages) > 0:
             self.process_new_messages(new_messages)
@@ -140,6 +144,8 @@ class TeleBot:
             self.process_new_inline_query(new_inline_querys)
         if len(new_chosen_inline_results) > 0:
             self.process_new_chosen_inline_query(new_chosen_inline_results)
+        if len(new_callback_querys) > 0:
+            self.process_new_callback_query(new_callback_querys)
 
     def process_new_messages(self, new_messages):
         self._append_pre_next_step_handler()
@@ -154,6 +160,9 @@ class TeleBot:
     def process_new_chosen_inline_query(self, new_chosen_inline_querys):
         self._notify_command_handlers(self.chosen_inline_handlers, new_chosen_inline_querys)
 
+    def process_new_callback_query(self, new_callback_querys):
+        self._notify_command_handlers(self.callback_query_handlers, new_callback_querys)
+
     def __notify_update(self, new_messages):
         for listener in self.update_listener:
             self.__exec_task(listener, new_messages)
@@ -413,6 +422,33 @@ class TeleBot:
             apihelper.send_location(self.token, chat_id, latitude, longitude, reply_to_message_id, reply_markup,
                                     disable_notification))
 
+    def send_venue(self, chat_id, latitude, longitude, title, address, foursquare_id=None, disable_notification=None,
+                   reply_to_message_id=None, reply_markup=None):
+        """
+        Use this method to send information about a venue.
+        :param chat_id: Integer or String : Unique identifier for the target chat or username of the target channel
+        :param latitude: Float : Latitude of the venue
+        :param longitude: Float : Longitude of the venue
+        :param title: String : Name of the venue
+        :param address: String : Address of the venue
+        :param foursquare_id: String : Foursquare identifier of the venue
+        :param disable_notification:
+        :param reply_to_message_id:
+        :param reply_markup:
+        :return:
+        """
+        return types.Message.de_json(
+            apihelper.send_venue(self.token, chat_id, latitude, longitude, title, address, foursquare_id,
+                                 disable_notification, reply_to_message_id, reply_markup)
+        )
+
+    def send_contact(self, chat_id, phone_number, first_name, last_name=None, disable_notification=None,
+                     reply_to_message_id=None, reply_markup=None):
+        return types.Message.de_json(
+            apihelper.send_contact(self.token, chat_id, phone_number, first_name, last_name, disable_notification,
+                                   reply_to_message_id, reply_markup)
+        )
+
     def send_chat_action(self, chat_id, action):
         """
         Use this method when you need to tell the user that something is happening on the bot's side.
@@ -425,13 +461,47 @@ class TeleBot:
         """
         return apihelper.send_chat_action(self.token, chat_id, action)
 
+    def kick_chat_member(self, chat_id, user_id):
+        """
+        Use this method to kick a user from a group or a supergroup.
+        :param chat_id: Int or string : Unique identifier for the target group or username of the target supergroup
+        :param user_id: Int : Unique identifier of the target user
+        :return: types.Message
+        """
+        return apihelper.kick_chat_member(self.token, chat_id, user_id)
+
+    def unban_chat_member(self, chat_id, user_id):
+        return apihelper.unban_chat_member(self.token, chat_id, user_id)
+
+    def answer_callback_query(self, callback_query_id, text=None, show_alert=None):
+        return apihelper.answer_callback_query(self.token, callback_query_id, text, show_alert)
+
+    def edit_message_text(self, text, chat_id=None, message_id=None, inline_message_id=None, parse_mode=None,
+                          disable_web_page_preview=None, reply_markup=None):
+        result = apihelper.edit_message_text(self.token, text, chat_id, message_id, inline_message_id, parse_mode,
+                                        disable_web_page_preview, reply_markup)
+        if type(result) == bool:    # if edit inline message return is bool not Message.
+            return result
+        return types.Message.de_json(result)
+
+    def edit_message_replay_markup(self, chat_id=None, message_id=None, inline_message_id=None, reply_markup=None):
+        return types.Message.de_json(
+            apihelper.edit_message_replay_markup(self.token, chat_id, message_id, inline_message_id, reply_markup)
+        )
+
+    def edit_message_caption(self, caption, chat_id=None, message_id=None, inline_message_id=None, reply_markup=None):
+        return types.Message.de_json(
+            apihelper.edit_message_caption(self.token, caption, chat_id, message_id, inline_message_id, reply_markup)
+        )
+
     def reply_to(self, message, text, **kwargs):
         """
         Convenience function for `send_message(message.chat.id, text, reply_to_message_id=message.message_id, **kwargs)`
         """
         return self.send_message(message.chat.id, text, reply_to_message_id=message.message_id, **kwargs)
 
-    def answer_inline_query(self, inline_query_id, results, cache_time=None, is_personal=None, next_offset=None):
+    def answer_inline_query(self, inline_query_id, results, cache_time=None, is_personal=None, next_offset=None,
+                            switch_pm_text=None, switch_pm_parameter=None):
         """
         Use this method to send answers to an inline query. On success, True is returned.
         No more than 50 results per query are allowed.
@@ -440,9 +510,24 @@ class TeleBot:
         :param cache_time: The maximum amount of time in seconds that the result of the inline query may be cached on the server.
         :param is_personal: Pass True, if results may be cached on the server side only for the user that sent the query.
         :param next_offset: Pass the offset that a client should send in the next query with the same text to receive more results.
+        :param switch_pm_parameter: If passed, clients will display a button with specified text that switches the user
+         to a private chat with the bot and sends the bot a start message with the parameter switch_pm_parameter
+        :param switch_pm_text: 	Parameter for the start message sent to the bot when user presses the switch button
         :return: True means success.
         """
-        return apihelper.answer_inline_query(self.token, inline_query_id, results, cache_time, is_personal, next_offset)
+        return apihelper.answer_inline_query(self.token, inline_query_id, results, cache_time, is_personal, next_offset,
+                                             switch_pm_text, switch_pm_parameter)
+
+    def answer_callback_query(self, callback_query_id, text=None, show_alert=None):
+        """
+        Use this method to send answers to callback queries sent from inline keyboards. The answer will be displayed to
+        the user as a notification at the top of the chat screen or as an alert.
+        :param callback_query_id:
+        :param text:
+        :param show_alert:
+        :return:
+        """
+        return apihelper.answer_callback_query(self.token, callback_query_id, text, show_alert)
 
     def register_for_reply(self, message, callback):
         """
@@ -596,6 +681,22 @@ class TeleBot:
 
         self.chosen_inline_handlers.append(handler_dict)
 
+    def callback_query_handler(self, func):
+        def decorator(handler):
+            self.add_callback_query_handler(handler, func)
+
+        return decorator
+
+    def add_callback_query_handler(self, handler, func):
+        filters = {'lambda': func}
+
+        handler_dict = {
+            'function': handler,
+            'filters': filters
+        }
+
+        self.callback_query_handlers.append(handler_dict)
+
     @staticmethod
     def _test_message_handler(message_handler, message):
         for filter, filter_value in six.iteritems(message_handler['filters']):
