@@ -10,6 +10,9 @@ logger = telebot.logger
 API_URL = "https://api.telegram.org/bot{0}/{1}"
 FILE_URL = "https://api.telegram.org/file/bot{0}/{1}"
 
+CONNECT_TIMEOUT = 3.5
+READ_TIMEOUT = 9999
+
 
 def _make_request(token, method_name, method='get', params=None, files=None, base_url=API_URL):
     """
@@ -23,7 +26,10 @@ def _make_request(token, method_name, method='get', params=None, files=None, bas
     """
     request_url = base_url.format(token, method_name)
     logger.debug("Request: method={0} url={1} params={2} files={3}".format(method, request_url, params, files))
-    result = requests.request(method, request_url, params=params, files=files)
+    read_timeout = READ_TIMEOUT
+    if params:
+        if 'timeout' in params: read_timeout = params['timeout'] + 10
+    result = requests.request(method, request_url, params=params, files=files, timeout=(CONNECT_TIMEOUT, read_timeout))
     logger.debug("The server returned: '{0}'".format(result.text.encode('utf8')))
     return _check_result(method_name, result)['result']
 
@@ -182,6 +188,36 @@ def send_location(token, chat_id, latitude, longitude, reply_to_message_id=None,
     return _make_request(token, method_url, params=payload)
 
 
+def send_venue(token, chat_id, latitude, longitude, title, address, foursquare_id=None, disable_notification=None,
+               reply_to_message_id=None, reply_markup=None):
+    method_url = r'sendVenue'
+    payload = {'chat_id': chat_id, 'latitude': latitude, 'longitude': longitude, 'title': title, 'address': address}
+    if foursquare_id:
+        payload['foursquare_id'] = foursquare_id
+    if disable_notification:
+        payload['disable_notification'] = disable_notification
+    if reply_to_message_id:
+        payload['reply_to_message_id'] = reply_to_message_id
+    if reply_markup:
+        payload['reply_markup'] = _convert_markup(reply_markup)
+    return _make_request(token, method_url, params=payload)
+
+
+def send_contact(token, chat_id, phone_number, first_name, last_name=None, disable_notification=None,
+                 reply_to_message_id=None, reply_markup=None):
+    method_url = r'sendContact'
+    payload = {'chat_id': chat_id, 'phone_number': phone_number, 'first_name': first_name}
+    if last_name:
+        payload['last_name'] = last_name
+    if disable_notification:
+        payload['disable_notification'] = disable_notification
+    if reply_to_message_id:
+        payload['reply_to_message_id'] = reply_to_message_id
+    if reply_markup:
+        payload['reply_markup'] = _convert_markup(reply_markup)
+    return _make_request(token, method_url, params=payload)
+
+
 def send_chat_action(token, chat_id, action):
     method_url = r'sendChatAction'
     payload = {'chat_id': chat_id, 'action': action}
@@ -278,15 +314,103 @@ def get_method_by_type(data_type):
         return r'sendSticker'
 
 
-def answer_inline_query(token, inline_query_id, results, cache_time=None, is_personal=None, next_offset=None):
+def kick_chat_member(token, chat_id, user_id):
+    method_url = 'kickChatMember'
+    payload = {'chat_id': chat_id, 'user_id': user_id}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def unban_chat_member(token, chat_id, user_id):
+    method_url = 'unbanChatMember'
+    payload = {'chat_id': chat_id, 'user_id': user_id}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+# Updating messages
+
+def edit_message_text(token, text, chat_id=None, message_id=None, inline_message_id=None, parse_mode=None,
+                      disable_web_page_preview=None, reply_markup=None):
+    method_url = r'editMessageText'
+    payload = {'text': text}
+    if chat_id:
+        payload['chat_id'] = chat_id
+    if message_id:
+        payload['message_id'] = message_id
+    if inline_message_id:
+        payload['inline_message_id'] = inline_message_id
+    if parse_mode:
+        payload['parse_mode'] = parse_mode
+    if disable_web_page_preview:
+        payload['disable_web_page_preview'] = disable_web_page_preview
+    if reply_markup:
+        payload['reply_markup'] = _convert_markup(reply_markup)
+    return _make_request(token, method_url, params=payload)
+
+
+def edit_message_caption(token, caption, chat_id=None, message_id=None, inline_message_id=None, reply_markup=None):
+    method_url = r'editMessageCaption'
+    payload = {'caption': caption}
+    if chat_id:
+        payload['chat_id'] = chat_id
+    if message_id:
+        payload['message_id'] = message_id
+    if inline_message_id:
+        payload['inline_message_id'] = inline_message_id
+    if reply_markup:
+        payload['reply_markup'] = _convert_markup(reply_markup)
+    return _make_request(token, method_url, params=payload)
+
+
+def edit_message_replay_markup(token, chat_id=None, message_id=None, inline_message_id=None, reply_markup=None):
+    method_url = r'editMessageReplyMarkup'
+    payload = {}
+    if chat_id:
+        payload['chat_id'] = chat_id
+    if message_id:
+        payload['message_id'] = message_id
+    if inline_message_id:
+        payload['inline_message_id'] = inline_message_id
+    if reply_markup:
+        payload['reply_markup'] = _convert_markup(reply_markup)
+    return _make_request(token, method_url, params=payload)
+
+
+# InlineQuery
+
+def answer_callback_query(token, callback_query_id, text=None, show_alert=None):
+    method_url = 'answerCallbackQuery'
+    payload = {'callback_query_id': callback_query_id}
+    if text:
+        payload['text'] = text
+    if show_alert:
+        payload['show_alert'] = show_alert
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def answer_inline_query(token, inline_query_id, results, cache_time=None, is_personal=None, next_offset=None,
+                        switch_pm_text=None, switch_pm_parameter=None):
     method_url = 'answerInlineQuery'
     payload = {'inline_query_id': inline_query_id, 'results': _convert_inline_results(results)}
     if cache_time:
         payload['cache_time'] = cache_time
     if is_personal:
         payload['is_personal'] = is_personal
-    if next_offset:
+    if next_offset is not None:
         payload['next_offset'] = next_offset
+    if switch_pm_text:
+        payload['switch_pm_text'] = switch_pm_text
+    if switch_pm_parameter:
+        payload['switch_pm_parameter'] = switch_pm_parameter
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def answer_callback_query(token, callback_query_id, text=None, show_alert=None):
+    method_url = 'answerCallbackQuery'
+    payload = {'callback_query_id': callback_query_id}
+    if text:
+        payload['text'] = text
+    if show_alert:
+        payload['show_alert'] = show_alert
     return _make_request(token, method_url, params=payload, method='post')
 
 
